# Changelog

All notable changes to this project will be documented in this file.

## [0.1.0] - 2025-11-01

### 🚀 Features

- migrate src and tests from chaos-box

### ⚙️ Miscellaneous Tasks

- init commit
- impl github workflows
- add CHANGELOG.md

<!-- generated by git-cliff -->
